@@ -6,7 +6,7 @@ import (
 	"path/filepath"
 	"sync"
 
-	vfs "github.com/twpayne/go-vfs/v4"
+	vfs "github.com/twpayne/go-vfs/v5"
 )
 
 // An RealSystem is a System that writes to a filesystem and executes scripts.
@@ -62,8 +62,7 @@ func (s *RealSystem) WriteFile(filename AbsPath, data []byte, perm fs.FileMode)
 
 // WriteSymlink implements System.WriteSymlink.
 func (s *RealSystem) WriteSymlink(oldname string, newname AbsPath) error {
-	if err := s.fileSystem.RemoveAll(newname.String()); err != nil &&
-		!errors.Is(err, fs.ErrNotExist) {
+	if err := s.fileSystem.RemoveAll(newname.String()); err != nil && !errors.Is(err, fs.ErrNotExist) {
 		return err
 	}
 	return s.fileSystem.Symlink(filepath.FromSlash(oldname), newname.String())
